@@ -25,11 +25,18 @@
  *
  */
 
+#if !defined(__ASOUNDLIB_H) && !defined(ALSA_LIBRARY_BUILD)
+/* don't use ALSA_LIBRARY_BUILD define in sources outside alsa-lib */
+#warning "use #include <alsa/asoundlib.h>, <alsa/global.h> should not be used directly"
+#include <alsa/asoundlib.h>
+#endif
 #ifndef __ALSA_GLOBAL_H_
 #define __ALSA_GLOBAL_H_
 
-/* for timeval and timespec */
-#include <time.h>
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #if defined(__FreeBSD__)
 #include <sys/timespec.h>
 #endif
@@ -38,10 +45,6 @@
 #include <alloca.h>
 #endif
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 /**
  *  \defgroup Global Global defines and functions
  *  Global defines and functions.
